diff --git a/app/migrations/Version20161117163856.php b/app/migrations/Version20161117163856.php
new file mode 100644
index 0000000000..5f9f7d2dbb
--- /dev/null
+++ b/app/migrations/Version20161117163856.php
@@ -0,0 +1,42 @@
+abortIf($this->connection->getDatabasePlatform()->getName() != 'mysql', 'Migration can only be executed safely on \'mysql\'.');
+
+ $this->addSql('ALTER TABLE sylius_channel DROP FOREIGN KEY FK_16C8119EECD792C0');
+ $this->addSql('DROP INDEX IDX_16C8119EECD792C0 ON sylius_channel');
+ $this->addSql('ALTER TABLE sylius_channel CHANGE default_currency_id base_currency_id INT NOT NULL');
+ $this->addSql('ALTER TABLE sylius_channel ADD CONSTRAINT FK_16C8119E3101778E FOREIGN KEY (base_currency_id) REFERENCES sylius_currency (id)');
+ $this->addSql('CREATE INDEX IDX_16C8119E3101778E ON sylius_channel (base_currency_id)');
+ }
+
+ /**
+ * @param Schema $schema
+ */
+ public function down(Schema $schema)
+ {
+ // this down() migration is auto-generated, please modify it to your needs
+ $this->abortIf($this->connection->getDatabasePlatform()->getName() != 'mysql', 'Migration can only be executed safely on \'mysql\'.');
+
+ $this->addSql('ALTER TABLE sylius_channel DROP FOREIGN KEY FK_16C8119E3101778E');
+ $this->addSql('DROP INDEX IDX_16C8119E3101778E ON sylius_channel');
+ $this->addSql('ALTER TABLE sylius_channel CHANGE base_currency_id default_currency_id INT NOT NULL');
+ $this->addSql('ALTER TABLE sylius_channel ADD CONSTRAINT FK_16C8119EECD792C0 FOREIGN KEY (default_currency_id) REFERENCES sylius_currency (id)');
+ $this->addSql('CREATE INDEX IDX_16C8119EECD792C0 ON sylius_channel (default_currency_id)');
+ }
+}
diff --git a/features/channel/managing_channels/adding_channel.feature b/features/channel/managing_channels/adding_channel.feature
index 57fe8629b5..bab1040139 100644
--- a/features/channel/managing_channels/adding_channel.feature
+++ b/features/channel/managing_channels/adding_channel.feature
@@ -14,7 +14,7 @@ Feature: Adding a new channel
Given I want to create a new channel
When I specify its code as "MOBILE"
And I name it "Mobile channel"
- And I choose "Euro" as a default currency
+ And I choose "Euro" as the base currency
And I choose "English (United States)" as a default locale
And I add it
Then I should be notified that it has been successfully created
@@ -28,7 +28,7 @@ Feature: Adding a new channel
And I describe it as "Main distribution channel for mobile apps"
And I set its hostname as "m.avengers-gear.com"
And I define its color as "blue"
- And I choose "Euro" as a default currency
+ And I choose "Euro" as the base currency
And I choose "English (United States)" as a default locale
And I add it
Then I should be notified that it has been successfully created
diff --git a/features/channel/managing_channels/channel_validation.feature b/features/channel/managing_channels/channel_validation.feature
index 90db1b57bf..0971f2159d 100644
--- a/features/channel/managing_channels/channel_validation.feature
+++ b/features/channel/managing_channels/channel_validation.feature
@@ -26,12 +26,12 @@ Feature: Channel validation
And channel with code "MOBILE" should not be added
@ui
- Scenario: Trying to add a new channel without default currency
+ Scenario: Trying to add a new channel without base currency
Given I want to create a new channel
When I specify its code as "MOBILE"
- But I do not choose default currency
+ But I do not choose base currency
And I try to add it
- Then I should be notified that default currency is required
+ Then I should be notified that base currency is required
And channel with code "MOBILE" should not be added
@ui
diff --git a/features/channel/managing_channels/not_being_able_to_add_disabled_channel_when_no_other_exist.feature b/features/channel/managing_channels/not_being_able_to_add_disabled_channel_when_no_other_exist.feature
index f5ebcde43a..15e323cf68 100644
--- a/features/channel/managing_channels/not_being_able_to_add_disabled_channel_when_no_other_exist.feature
+++ b/features/channel/managing_channels/not_being_able_to_add_disabled_channel_when_no_other_exist.feature
@@ -14,7 +14,7 @@ Feature: Not being able to add a disabled channel when no other exist
Given I want to create a new channel
When I specify its code as "MOBILE"
And I name it "Mobile channel"
- And I choose "Euro" as a default currency
+ And I choose "Euro" as the base currency
And I choose "English (United States)" as a default locale
And I disable it
And I add it
diff --git a/features/channel/managing_channels/selecting_default_tax_zone_for_channel.feature b/features/channel/managing_channels/selecting_default_tax_zone_for_channel.feature
index 3ee5ae8daf..15894e7031 100644
--- a/features/channel/managing_channels/selecting_default_tax_zone_for_channel.feature
+++ b/features/channel/managing_channels/selecting_default_tax_zone_for_channel.feature
@@ -14,7 +14,7 @@ Feature: Selecting default tax zone for a channel
When I specify its code as "MOBILE"
And I name it "Mobile store"
And I select the "United States" as default tax zone
- And I choose "USD" as a default currency
+ And I choose "USD" as the base currency
And I choose "English (United States)" as a default locale
And I add it
Then I should be notified that it has been successfully created
diff --git a/features/channel/managing_channels/selecting_locales_available_for_channel.feature b/features/channel/managing_channels/selecting_locales_available_for_channel.feature
index c6ffe7c2b2..b1ba61df92 100644
--- a/features/channel/managing_channels/selecting_locales_available_for_channel.feature
+++ b/features/channel/managing_channels/selecting_locales_available_for_channel.feature
@@ -15,7 +15,7 @@ Feature: Selecting available locales for a channel
When I specify its code as "MOBILE"
And I name it "Mobile channel"
And I make it available in "English (United States)"
- And I choose "Euro" as a default currency
+ And I choose "Euro" as the base currency
And I choose "English (United States)" as a default locale
And I add it
Then I should be notified that it has been successfully created
diff --git a/features/channel/managing_channels/selecting_tax_calculation_strategy_for_channel.feature b/features/channel/managing_channels/selecting_tax_calculation_strategy_for_channel.feature
index c40448e5e6..0309571c55 100644
--- a/features/channel/managing_channels/selecting_tax_calculation_strategy_for_channel.feature
+++ b/features/channel/managing_channels/selecting_tax_calculation_strategy_for_channel.feature
@@ -14,7 +14,7 @@ Feature: Selecting tax calculation strategy for a channel
Given I want to create a new channel
When I specify its code as "MOBILE"
And I name it "Mobile store"
- And I choose "Euro" as a default currency
+ And I choose "Euro" as the base currency
And I choose "English (United States)" as a default locale
And I add it
Then I should be notified that it has been successfully created
@@ -26,7 +26,7 @@ Feature: Selecting tax calculation strategy for a channel
When I specify its code as "MOBILE"
And I select the "Order item units based" as tax calculation strategy
And I name it "Mobile store"
- And I choose "Euro" as a default currency
+ And I choose "Euro" as the base currency
And I choose "English (United States)" as a default locale
And I add it
Then I should be notified that it has been successfully created
diff --git a/src/Sylius/Behat/Context/Setup/CurrencyContext.php b/src/Sylius/Behat/Context/Setup/CurrencyContext.php
index 67734cd28e..fe25f11605 100644
--- a/src/Sylius/Behat/Context/Setup/CurrencyContext.php
+++ b/src/Sylius/Behat/Context/Setup/CurrencyContext.php
@@ -152,7 +152,7 @@ final class CurrencyContext implements Context
$currency = $this->provideCurrency($currencyCode);
$channel->addCurrency($currency);
- $channel->setDefaultCurrency($currency);
+ $channel->setBaseCurrency($currency);
$this->channelManager->flush();
diff --git a/src/Sylius/Behat/Page/Admin/Channel/CreatePage.php b/src/Sylius/Behat/Page/Admin/Channel/CreatePage.php
index 408228ac4a..9943aa1743 100644
--- a/src/Sylius/Behat/Page/Admin/Channel/CreatePage.php
+++ b/src/Sylius/Behat/Page/Admin/Channel/CreatePage.php
@@ -81,11 +81,11 @@ class CreatePage extends BaseCreatePage implements CreatePageInterface
/**
* {@inheritdoc}
*/
- public function chooseDefaultCurrency($currency)
+ public function chooseBaseCurrency($currency)
{
if (null !== $currency) {
$this->getElement('currencies')->selectOption($currency);
- $this->getElement('default_currency')->selectOption($currency);
+ $this->getElement('base_currency')->selectOption($currency);
}
}
@@ -113,7 +113,7 @@ class CreatePage extends BaseCreatePage implements CreatePageInterface
return array_merge(parent::getDefinedElements(), [
'code' => '#sylius_channel_code',
'currencies' => '#sylius_channel_currencies',
- 'default_currency' => '#sylius_channel_defaultCurrency',
+ 'base_currency' => '#sylius_channel_baseCurrency',
'default_locale' => '#sylius_channel_defaultLocale',
'enabled' => '#sylius_channel_enabled',
'locales' => '#sylius_channel_locales',
diff --git a/src/Sylius/Behat/Page/Admin/Channel/CreatePageInterface.php b/src/Sylius/Behat/Page/Admin/Channel/CreatePageInterface.php
index 90cb35709e..1a82e5f957 100644
--- a/src/Sylius/Behat/Page/Admin/Channel/CreatePageInterface.php
+++ b/src/Sylius/Behat/Page/Admin/Channel/CreatePageInterface.php
@@ -70,7 +70,7 @@ interface CreatePageInterface extends BaseCreatePageInterface
/**
* @param string $currency
*/
- public function chooseDefaultCurrency($currency);
+ public function chooseBaseCurrency($currency);
/**
* @param string $taxCalculationStrategy
diff --git a/src/Sylius/Bundle/AdminBundle/Resources/views/Channel/_form.html.twig b/src/Sylius/Bundle/AdminBundle/Resources/views/Channel/_form.html.twig
index 287cd2a1f9..7eb6725b12 100644
--- a/src/Sylius/Bundle/AdminBundle/Resources/views/Channel/_form.html.twig
+++ b/src/Sylius/Bundle/AdminBundle/Resources/views/Channel/_form.html.twig
@@ -28,7 +28,7 @@
{{ form_row(form.locales) }}
{{ form_row(form.defaultLocale) }}
{{ form_row(form.currencies) }}
- {{ form_row(form.defaultCurrency) }}
+ {{ form_row(form.baseCurrency) }}
{{ form_row(form.defaultTaxZone) }}
{{ form_row(form.taxCalculationStrategy) }}
diff --git a/src/Sylius/Bundle/CoreBundle/Command/SetupCommand.php b/src/Sylius/Bundle/CoreBundle/Command/SetupCommand.php
index 3d2a048119..fcd845ce77 100644
--- a/src/Sylius/Bundle/CoreBundle/Command/SetupCommand.php
+++ b/src/Sylius/Bundle/CoreBundle/Command/SetupCommand.php
@@ -189,7 +189,7 @@ EOT
$channel->addCurrency($this->currency);
$channel->addLocale($this->locale);
- $channel->setDefaultCurrency($this->currency);
+ $channel->setBaseCurrency($this->currency);
$channel->setDefaultLocale($this->locale);
$channelManager->flush();
diff --git a/src/Sylius/Bundle/CoreBundle/Fixture/ChannelFixture.php b/src/Sylius/Bundle/CoreBundle/Fixture/ChannelFixture.php
index cb4ac8f93b..565781d927 100644
--- a/src/Sylius/Bundle/CoreBundle/Fixture/ChannelFixture.php
+++ b/src/Sylius/Bundle/CoreBundle/Fixture/ChannelFixture.php
@@ -41,7 +41,7 @@ final class ChannelFixture extends AbstractResourceFixture
->booleanNode('enabled')->end()
->scalarNode('default_locale')->cannotBeEmpty()->end()
->arrayNode('locales')->prototype('scalar')->end()->end()
- ->scalarNode('default_currency')->cannotBeEmpty()->end()
+ ->scalarNode('base_currency')->cannotBeEmpty()->end()
->arrayNode('currencies')->prototype('scalar')->end()->end()
->scalarNode('theme_name')->end()
;
diff --git a/src/Sylius/Bundle/CoreBundle/Fixture/Factory/ChannelExampleFactory.php b/src/Sylius/Bundle/CoreBundle/Fixture/Factory/ChannelExampleFactory.php
index cd19ffb342..1d7be06595 100644
--- a/src/Sylius/Bundle/CoreBundle/Fixture/Factory/ChannelExampleFactory.php
+++ b/src/Sylius/Bundle/CoreBundle/Fixture/Factory/ChannelExampleFactory.php
@@ -82,11 +82,11 @@ final class ChannelExampleFactory implements ExampleFactoryInterface
->setDefault('locales', LazyOption::all($localeRepository))
->setAllowedTypes('locales', 'array')
->setNormalizer('locales', LazyOption::findBy($localeRepository, 'code'))
- ->setDefault('default_currency', function (Options $options) {
+ ->setDefault('base_currency', function (Options $options) {
return $this->faker->randomElement($options['currencies']);
})
- ->setAllowedTypes('default_currency', ['string', CurrencyInterface::class])
- ->setNormalizer('default_currency', LazyOption::findOneBy($currencyRepository, 'code'))
+ ->setAllowedTypes('base_currency', ['string', CurrencyInterface::class])
+ ->setNormalizer('base_currency', LazyOption::findOneBy($currencyRepository, 'code'))
->setDefault('currencies', LazyOption::all($currencyRepository))
->setAllowedTypes('currencies', 'array')
->setNormalizer('currencies', LazyOption::findBy($currencyRepository, 'code'))
@@ -115,7 +115,7 @@ final class ChannelExampleFactory implements ExampleFactoryInterface
$channel->addLocale($locale);
}
- $channel->setDefaultCurrency($options['default_currency']);
+ $channel->setBaseCurrency($options['base_currency']);
foreach ($options['currencies'] as $currency) {
$channel->addCurrency($currency);
}
diff --git a/src/Sylius/Bundle/CoreBundle/Form/Type/ChannelType.php b/src/Sylius/Bundle/CoreBundle/Form/Type/ChannelType.php
index a659a939e4..18813c2e65 100644
--- a/src/Sylius/Bundle/CoreBundle/Form/Type/ChannelType.php
+++ b/src/Sylius/Bundle/CoreBundle/Form/Type/ChannelType.php
@@ -42,8 +42,8 @@ class ChannelType extends BaseChannelType
'required' => true,
'multiple' => true,
])
- ->add('defaultCurrency', 'sylius_currency_choice', [
- 'label' => 'sylius.form.channel.currency_default',
+ ->add('baseCurrency', 'sylius_currency_choice', [
+ 'label' => 'sylius.form.channel.currency_base',
'required' => true,
])
->add('defaultTaxZone', 'sylius_zone_choice', [
diff --git a/src/Sylius/Bundle/CoreBundle/Resources/config/doctrine/model/Channel.orm.xml b/src/Sylius/Bundle/CoreBundle/Resources/config/doctrine/model/Channel.orm.xml
index a2c1c235a2..b4a3f96701 100644
--- a/src/Sylius/Bundle/CoreBundle/Resources/config/doctrine/model/Channel.orm.xml
+++ b/src/Sylius/Bundle/CoreBundle/Resources/config/doctrine/model/Channel.orm.xml
@@ -23,8 +23,8 @@
-
-
+
+
diff --git a/src/Sylius/Bundle/CoreBundle/Resources/config/validation/Channel.xml b/src/Sylius/Bundle/CoreBundle/Resources/config/validation/Channel.xml
index 910a9b5cff..2fb70c16f1 100644
--- a/src/Sylius/Bundle/CoreBundle/Resources/config/validation/Channel.xml
+++ b/src/Sylius/Bundle/CoreBundle/Resources/config/validation/Channel.xml
@@ -16,9 +16,9 @@
-
+
-
+
diff --git a/src/Sylius/Bundle/CoreBundle/Resources/translations/messages.en.yml b/src/Sylius/Bundle/CoreBundle/Resources/translations/messages.en.yml
index 39ce9b2a7b..e267b51c3b 100644
--- a/src/Sylius/Bundle/CoreBundle/Resources/translations/messages.en.yml
+++ b/src/Sylius/Bundle/CoreBundle/Resources/translations/messages.en.yml
@@ -27,7 +27,7 @@ sylius:
taxonomies: Taxonomies
locale_default: Default locale
locales: Locales
- currency_default: Default currency
+ currency_base: Base currency
currencies: Currencies
shipping_methods: Shipping Methods
payment_methods: Payment Methods
diff --git a/src/Sylius/Bundle/CoreBundle/Resources/translations/validators.en.yml b/src/Sylius/Bundle/CoreBundle/Resources/translations/validators.en.yml
index a98852cced..dace4f9937 100644
--- a/src/Sylius/Bundle/CoreBundle/Resources/translations/validators.en.yml
+++ b/src/Sylius/Bundle/CoreBundle/Resources/translations/validators.en.yml
@@ -1,7 +1,7 @@
sylius:
channel:
- default_currency:
- not_blank: Please enter channel default currency.
+ base_currency:
+ not_blank: Please enter channel base currency.
default_locale:
not_blank: Please enter channel default locale.
checkout:
diff --git a/src/Sylius/Component/Core/Model/Channel.php b/src/Sylius/Component/Core/Model/Channel.php
index c880e326e4..f95d6a90b1 100644
--- a/src/Sylius/Component/Core/Model/Channel.php
+++ b/src/Sylius/Component/Core/Model/Channel.php
@@ -26,7 +26,7 @@ class Channel extends BaseChannel implements ChannelInterface
/**
* @var CurrencyInterface
*/
- protected $defaultCurrency;
+ protected $baseCurrency;
/**
* @var LocaleInterface
@@ -69,17 +69,17 @@ class Channel extends BaseChannel implements ChannelInterface
/**
* {@inheritdoc}
*/
- public function getDefaultCurrency()
+ public function getBaseCurrency()
{
- return $this->defaultCurrency;
+ return $this->baseCurrency;
}
/**
* {@inheritdoc}
*/
- public function setDefaultCurrency(CurrencyInterface $defaultCurrency)
+ public function setBaseCurrency(CurrencyInterface $baseCurrency)
{
- $this->defaultCurrency = $defaultCurrency;
+ $this->baseCurrency = $baseCurrency;
}
/**
diff --git a/src/Sylius/Component/Core/Model/ChannelInterface.php b/src/Sylius/Component/Core/Model/ChannelInterface.php
index 86b20f96b6..b0cf1dcbca 100644
--- a/src/Sylius/Component/Core/Model/ChannelInterface.php
+++ b/src/Sylius/Component/Core/Model/ChannelInterface.php
@@ -39,12 +39,12 @@ interface ChannelInterface extends
/**
* @return CurrencyInterface
*/
- public function getDefaultCurrency();
+ public function getBaseCurrency();
/**
* @param CurrencyInterface $currency
*/
- public function setDefaultCurrency(CurrencyInterface $currency);
+ public function setBaseCurrency(CurrencyInterface $currency);
/**
* @return ZoneInterface
diff --git a/src/Sylius/Component/Core/Provider/ChannelBasedCurrencyProvider.php b/src/Sylius/Component/Core/Provider/ChannelBasedCurrencyProvider.php
index 86aba4c5a1..8138d90f1d 100644
--- a/src/Sylius/Component/Core/Provider/ChannelBasedCurrencyProvider.php
+++ b/src/Sylius/Component/Core/Provider/ChannelBasedCurrencyProvider.php
@@ -69,7 +69,7 @@ final class ChannelBasedCurrencyProvider implements CurrencyProviderInterface
/** @var ChannelInterface $channel */
$channel = $this->channelContext->getChannel();
- return $channel->getDefaultCurrency()->getCode();
+ return $channel->getBaseCurrency()->getCode();
} catch (ChannelNotFoundException $exception) {
throw new CurrencyNotFoundException(null, $exception);
}
diff --git a/src/Sylius/Component/Core/Test/Services/DefaultChannelFactory.php b/src/Sylius/Component/Core/Test/Services/DefaultChannelFactory.php
index cadcf09764..eb516e9c04 100644
--- a/src/Sylius/Component/Core/Test/Services/DefaultChannelFactory.php
+++ b/src/Sylius/Component/Core/Test/Services/DefaultChannelFactory.php
@@ -110,7 +110,7 @@ final class DefaultChannelFactory implements DefaultChannelFactoryInterface
$channel->setTaxCalculationStrategy('order_items_based');
$channel->addCurrency($currency);
- $channel->setDefaultCurrency($currency);
+ $channel->setBaseCurrency($currency);
$channel->addLocale($locale);
$channel->setDefaultLocale($locale);
diff --git a/src/Sylius/Component/Core/Test/Services/DefaultUnitedStatesChannelFactory.php b/src/Sylius/Component/Core/Test/Services/DefaultUnitedStatesChannelFactory.php
index 6b795b7f7c..6bba834bfa 100644
--- a/src/Sylius/Component/Core/Test/Services/DefaultUnitedStatesChannelFactory.php
+++ b/src/Sylius/Component/Core/Test/Services/DefaultUnitedStatesChannelFactory.php
@@ -160,7 +160,7 @@ final class DefaultUnitedStatesChannelFactory implements DefaultChannelFactoryIn
$channel = $this->createChannel($code ?: self::DEFAULT_CHANNEL_CODE, $name ?: self::DEFAULT_CHANNEL_NAME);
$channel->addCurrency($currency);
- $channel->setDefaultCurrency($currency);
+ $channel->setBaseCurrency($currency);
$channel->addLocale($locale);
$channel->setDefaultLocale($locale);
$channel->setTaxCalculationStrategy('order_items_based');
diff --git a/src/Sylius/Component/Core/spec/Provider/ChannelBasedCurrencyProviderSpec.php b/src/Sylius/Component/Core/spec/Provider/ChannelBasedCurrencyProviderSpec.php
index 2c42fe86d3..8ee0a4580d 100644
--- a/src/Sylius/Component/Core/spec/Provider/ChannelBasedCurrencyProviderSpec.php
+++ b/src/Sylius/Component/Core/spec/Provider/ChannelBasedCurrencyProviderSpec.php
@@ -62,14 +62,14 @@ final class ChannelBasedCurrencyProviderSpec extends ObjectBehavior
$this->getAvailableCurrenciesCodes()->shouldReturn(['BTC']);
}
- function it_returns_channels_default_currency(
+ function it_returns_channels_base_currency(
ChannelContextInterface $channelContext,
ChannelInterface $channel,
CurrencyInterface $currency
) {
$channelContext->getChannel()->willReturn($channel);
- $channel->getDefaultCurrency()->willReturn($currency);
+ $channel->getBaseCurrency()->willReturn($currency);
$currency->getCode()->willReturn('BTC');
diff --git a/src/Sylius/Component/Core/spec/Test/Services/DefaultChannelFactorySpec.php b/src/Sylius/Component/Core/spec/Test/Services/DefaultChannelFactorySpec.php
index 2101ca2e10..dd27595a84 100644
--- a/src/Sylius/Component/Core/spec/Test/Services/DefaultChannelFactorySpec.php
+++ b/src/Sylius/Component/Core/spec/Test/Services/DefaultChannelFactorySpec.php
@@ -80,7 +80,7 @@ final class DefaultChannelFactorySpec extends ObjectBehavior
$channel->setTaxCalculationStrategy('order_items_based')->shouldBeCalled();
$channel->addCurrency($currency)->shouldBeCalled();
- $channel->setDefaultCurrency($currency)->shouldBeCalled();
+ $channel->setBaseCurrency($currency)->shouldBeCalled();
$channel->addLocale($locale)->shouldBeCalled();
$channel->setDefaultLocale($locale)->shouldBeCalled();
diff --git a/src/Sylius/Component/Core/spec/Test/Services/DefaultUnitedStatesChannelFactorySpec.php b/src/Sylius/Component/Core/spec/Test/Services/DefaultUnitedStatesChannelFactorySpec.php
index ea16cfcf8c..830bb2fe78 100644
--- a/src/Sylius/Component/Core/spec/Test/Services/DefaultUnitedStatesChannelFactorySpec.php
+++ b/src/Sylius/Component/Core/spec/Test/Services/DefaultUnitedStatesChannelFactorySpec.php
@@ -71,7 +71,7 @@ final class DefaultUnitedStatesChannelFactorySpec extends ObjectBehavior
$this->shouldImplement(DefaultChannelFactoryInterface::class);
}
- function it_creates_a_default_united_states_channel_with_country_zone_and_usd_as_default_currency(
+ function it_creates_a_default_united_states_channel_with_country_zone_and_usd_as_base_currency(
RepositoryInterface $channelRepository,
RepositoryInterface $countryRepository,
RepositoryInterface $currencyRepository,
@@ -116,7 +116,7 @@ final class DefaultUnitedStatesChannelFactorySpec extends ObjectBehavior
$currency->setCode('USD')->shouldBeCalled();
$currency->setExchangeRate(1.00)->shouldBeCalled();
- $channel->setDefaultCurrency($currency)->shouldBeCalled();
+ $channel->setBaseCurrency($currency)->shouldBeCalled();
$channel->addCurrency($currency)->shouldBeCalled();
$channel->setDefaultLocale($locale)->shouldBeCalled();
$channel->addLocale($locale)->shouldBeCalled();
diff --git a/tests/DataFixtures/ORM/resources/channels.yml b/tests/DataFixtures/ORM/resources/channels.yml
index bf0fd0bd97..26ca8da683 100644
--- a/tests/DataFixtures/ORM/resources/channels.yml
+++ b/tests/DataFixtures/ORM/resources/channels.yml
@@ -4,7 +4,7 @@ Sylius\Component\Core\Model\Channel:
name: "Web Channel"
hostname: "localhost"
description: "Lorem ipsum"
- defaultCurrency: "@currency"
+ baseCurrency: "@currency"
defaultLocale: "@locale"
color: "black"
enabled: true
diff --git a/tests/DataFixtures/ORM/resources/checkout.yml b/tests/DataFixtures/ORM/resources/checkout.yml
index 44f22584f0..e7104614e1 100644
--- a/tests/DataFixtures/ORM/resources/checkout.yml
+++ b/tests/DataFixtures/ORM/resources/checkout.yml
@@ -22,7 +22,7 @@ Sylius\Component\Core\Model\Channel:
name: "Channel"
hostname: "localhost"
description: "Lorem ipsum"
- defaultCurrency: "@currency"
+ baseCurrency: "@currency"
defaultLocale: "@locale"
color: "black"
enabled: true
diff --git a/src/Sylius/Behat/Context/Ui/Admin/ManagingChannelsContext.php b/src/Sylius/Behat/Context/Ui/Admin/ManagingChannelsContext.php
index 4c89fb12da..ed085b3d35 100644
--- a/src/Sylius/Behat/Context/Ui/Admin/ManagingChannelsContext.php
+++ b/src/Sylius/Behat/Context/Ui/Admin/ManagingChannelsContext.php
@@ -102,12 +102,12 @@ final class ManagingChannelsContext implements Context
}
/**
* @When I choose :currency as a default currency
* @When I do not choose default currency
*/
- public function iChooseAsADefaultCurrency($currency = null)
+ public function iChooseAsABaseCurrency($currency = null)
{
- $this->createPage->chooseDefaultCurrency($currency);
+ $this->createPage->chooseBaseCurrency($currency);
}
/**
@@ -102,12 +102,12 @@ final class ManagingChannelsContext implements Context
}
/**
- * @When I choose :currency as a default currency
- * @When I do not choose default currency
+ * @When I choose :currency as the base currency
+ * @When I do not choose base currency
*/